// Import Data
forval y = 2003/2014 {
    import excel ohio_warn.xlsx, sheet("`y'") firstrow allstring clear
	tempfile oh`y'
    save `oh`y''
}
*

use `oh2003', clear
forval y = 2004/2014 {
    append using `oh`y''
}
*

g state = "OH"

g receive_date = date(DateRecd,"MDY")
g layoff_date = date(LayoffDate,"MDY")
format receive_date layoff_date %td

// Fix Dates
replace receive_date = mdy(3,22,2006) if ///
	DateRecd == "3/24/05 (Updated 6/6/05)" // Google Search Verified


g firm_name = upper(trim(Company))
g workers_affected = real(NumAffected)


// Extract City Name
g cp1 = strpos(City,"(")
g cp2 = strpos(City," (")
g cp3 = strpos(City,"/")
g cp4 = strpos(City,"/ ")

forval n = 1/4 {
    replace cp`n' = . if cp`n' == 0
}
*
replace cp1 = cp1-1 if cp1 != .
replace cp3 = cp3-1 if cp3 != .
replace cp4 = cp4-1 if cp4 != .

g city = trim(upper(substr(City,1,min(cp1,cp2,cp3,cp4))))
drop cp*

// Fix City Typos
replace city = "BROOK PARK" if city == "BROOKPARK"
replace city = "CINCINNATI" if city == "CINICNNATI"
replace city = "FREDERICKTOWN" if city == "FREDRICKTOWN"
replace city = "MASSILLON" if city == "MASSILLION"
replace city = "MC DONALD" if city == "MCDONALD"
replace city = "MIDDLEBURG HEIGHTS" if city == "MIDDLEBURG HTS" 
replace city = "MOUNT VERNON" if city == "MT. VERNON"
replace city = "NEW PHILADELPHIA" if city == "NEWPHILADELPHIA"
replace city = "NORTH RIDGEVILLE" if city == "NORTH RIDGESVILLE"
replace city = "SAINT CLAIRSVILLE" if city == "ST. CLAIRSVILLE"
replace city = "VERMILION" if city == "VERMILLION"
replace city = "WASHINGTON COURT HOUSE" if ///
	inlist(city,"WASHINGTON C.H.","WASHINGTON CH")


ren city muni
merge m:1 state muni using oh_muni_county_crosswalk, keep(1 3)
ren muni city

// Extract County Name
g cp5 = strpos(City,"(")
g cp6 = strpos(City,")")
g county_name2 = trim(upper(substr(City,cp5+1,cp6-cp5-1)))
replace county_name = county_name2 if county_name == ""

// Fix Counties that don't match
replace county_name = "CUYAHOGA" if (City == "Brooklyn andCleveland" | ///
   City == "Cleveland and Brooklyn" | City == "Warrensville")
replace county_name = "PORTAGE" if City == "Ravenna and Rootstown"
replace county_name = "LORAIN" if City == "Avon Lake and Elyria"
replace county_name = "HAMILTON" if City == "Sharonville"

// Location Flag
g flag_loc = .
replace flag_loc = 1 if City == "Richfield andIndependence"
replace flag_loc = 1 if City == "Sharonville"
replace flag_loc = 1 if City == "WPAFB/ Greene"
replace flag_loc = 2 if City == "Statewide"
replace flag_loc = 2 if City == "Various"
replace flag_loc = 2 if City == "Various/ Various"
replace flag_loc = 2 if City == "Various/ Lucas"
replace flag_loc = 2 if county_name == "VARIOUS"

sort receive_date


// Manual # of Workers Affected Fixes
g flag_affected = 0

replace workers_affected = 85 if NumAffected == "70 to 100"
replace flag_affected = 1 if NumAffected == "70 to 100"
replace workers_affected = 59 if NumAffected == "55 - 63"
replace flag_affected = 1 if NumAffected == "55 - 63"
replace workers_affected = 358 if NumAffected == "345 - 370"
replace flag_affected = 1 if NumAffected == "345 - 370"
replace workers_affected = 55 if NumAffected == "50 to 60"
replace flag_affected = 1 if NumAffected == "50 to 60"

replace workers_affected = 50 if NumAffected == "Over 50"
replace flag_affected = 2 if NumAffected == "Over 50"

replace workers_affected = 644 if NumAffected == "644 *updated"
replace flag_affected = 3 if NumAffected == "644 *updated"

replace flag_affected = 4 if inlist(NumAffected,"?","Unknown","N/A","unknown")
replace flag_affected = 5 if NumAffected == "4,133 in 46 locations in N.E. ohio"



/*
Case Specific Notes
Received 10oct2006, TOPS MARKETS, LLC (# 4,133 in 46 locations in N.E. ohio), For Info:
https://www2.topsmarkets.com/www2/pressreleases/company_press_article.cfm?press_id=227
https://www2.topsmarkets.com/www2/pressreleases/company_press_article.cfm?press_id=233
https://www2.topsmarkets.com/www2/pressreleases/company_press_article.cfm?press_id=238
*/


// Save Cleaned Data
keeporder receive_date layoff_date firm_name state city county_name ///
    workers_affected flag_loc flag_affected

save oh_warn, replace
